Downloading
===========


Latest Stable Release
---------------------

By design, there is currently no stable release planned.

The latest stable releases (if there should ever be one) could be downloaded from the
`Releases <https://github.com/isomeric/isomer/releases>`_ page
(*specifically the Tags tab*).


Latest Development Source Code
------------------------------

We use `Git <https://git-scm.com/>`_ for source control and code sharing.

The latest development branch can be cloned using the following command:

.. code-block:: sh
   
   git clone https://github.com/isomeric/isomer.git
   
For further instructions on how to use Git, please refer to the
`Git Website <https://git-scm.com/>`_.
